# VOTable to FITS
VOTables are slow to read. Yuck. This is a simple tool to convert time to FITS tables.

Nice.

## Installation

### Stable
```
pip install vot2fits
```

### Latest
```
pip install git+https://github.com/AlecThomson/vot2fits.git
```

## Usage
```
❯ vot2fits --help
Usage: vot2fits [OPTIONS] [FILE_NAMES]...

Options:
  -o, --overwrite  Overwrite existing files
  --help           Show this message and exit.
```

## License
MIT.